@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: addbiblio.pl,v 1.52.2.58.2.1 2007/04/27 13:08:28 tipaul Exp $
+# $Id: addbiblio.pl,v 1.52.2.40.2.2 2006/07/11 13:00:46 kados Exp $
 
 # Copyright 2000-2002 Katipo Communications
 #
@@ -26,6 +26,7 @@ use C4::Output;
 use C4::Interface::CGI::Output;
 use C4::Biblio;
 use C4::SearchMarc; # also includes Biblio.pm, SearchMarc is used to FindDuplicate
+use C4::Search;
 use C4::Context;
 use C4::Koha; # XXX subfield_is_koha_internal_p
 #use Smart::Comments;
@@ -94,7 +95,7 @@ sub MARCfindbreeding {
 	$sth->execute($id);
 	my ($file,$marc,$encoding) = $sth->fetchrow;
 	if ($marc) {
-		my $record = fixEncoding($marc);
+		my $record = MARC::File::USMARC::decode($marc);
 		if (ref($record) eq undef) {
 			return -1;
 		} else {
@@ -104,7 +105,7 @@ sub MARCfindbreeding {
 				my $auth_fields = C4::Context->preference("z3950AuthorAuthFields");
 				my @auth_fields= split /,/,$auth_fields;
 				my $field;
-				#warn $record->as_formatted;
+				warn $record->as_formatted;
 				if ($record->field($tag)){
 					foreach my $tmpfield ($record->field($tag)->subfields){
 #						foreach my $subfieldcode ($tmpfield->subfields){
@@ -116,7 +117,7 @@ sub MARCfindbreeding {
 							$field=MARC::Field->new($tag,"","",$subfieldcode=>$subfieldvalue) if ($subfieldcode ne $subfield);
 						}
 					}
-					#warn $field->as_formatted;
+					warn $field->as_formatted;
 #					}
 				}
 				$record->delete_field($record->field($tag));
@@ -136,7 +137,6 @@ sub MARCfindbreeding {
 				}
 				$record->insert_fields_ordered($field);
 			}
-# 			warn $record->as_formatted."";
 			return $record,$encoding;
 		}
 	}
@@ -226,7 +226,7 @@ sub create_input () {
 		$subfield_data{marc_value}= build_authorized_values_list($tag, $subfield, $value, $dbh,$authorised_values_sth);
 	# it's a thesaurus / authority field
 	} elsif ($tagslib->{$tag}->{$subfield}->{authtypecode}) {
-		$subfield_data{marc_value}="<input type=\"text\" name=\"field_value\" value=\"$value\" size=\"67\" maxlength=\"255\" DISABLE READONLY> <a href=\"javascript:Dopop('../authorities/auth_finder.pl?authtypecode=".$tagslib->{$tag}->{$subfield}->{authtypecode}."&index=$i',$i)\">...</a>";
+		$subfield_data{marc_value}="<input onblur=\"this.style.backgroundColor='#ffffff';\" onfocus=\"this.style.backgroundColor='#ffff00;'\"\" tabindex=\"1\" type=\"text\" name=\"field_value\" value=\"$value\" size=\"70\" maxlength=\"255\" DISABLE READONLY> <a  style=\"cursor: help;\" href=\"javascript:openAuth('tag$tag','$tagslib->{$tag}->{$subfield}->{authtypecode}','subfield$tag$i')\">...</a>";
 	# it's a plugin field
 	} elsif ($tagslib->{$tag}->{$subfield}->{'value_builder'}) {
 		# opening plugin. Just check wether we are on a developper computer on a production one
@@ -265,10 +265,6 @@ sub build_tabs ($$$$) {
 	my $authorised_values_sth = $dbh->prepare("select authorised_value,lib
 		from authorised_values
 		where category=? order by lib");
-    
-    # in this array, we will push all the 10 tabs
-    # to avoid having 10 tabs in the template : they will all be in the same BIG_LOOP
-    my @BIG_LOOP;
 
 # loop through each tab 0 through 9
 	for (my $tabloop = 0; $tabloop <= 9; $tabloop++) {
@@ -374,17 +370,8 @@ sub build_tabs ($$$$) {
 				}
 			}
 		}
-		if ($#loop_data >=0) {
-            my %big_loop_line;
-            $big_loop_line{number}=$tabloop;
-            $big_loop_line{innerloop}=\@loop_data;
-            push @BIG_LOOP,\%big_loop_line;
-        }
-# 		$template->param($tabloop."XX" =>\@loop_data);
+		$template->param($tabloop."XX" =>\@loop_data);
 	}
-# 	use Data::Dumper;
-# 	warn "DUMP : ".Dumper(@BIG_LOOP);
-	$template->param(BIG_LOOP => \@BIG_LOOP);
 }
 
 
@@ -475,7 +462,6 @@ $tagslib = &MARCgettagslib($dbh,1,$frameworkcode);
 my $record=-1;
 my $encoding="";
 $record = MARCgetbiblio($dbh,$bibid) if ($bibid);
-#warn "REC : ".$record->as_formatted;
 ($record,$encoding) = MARCfindbreeding($dbh,$breedingid) if ($breedingid);
 
 $is_a_modif=0;
@@ -501,18 +487,11 @@ if ($op eq "addbiblio") {
 	# build indicator hash.
 	my @ind_tag = $input->param('ind_tag');
 	my @indicator = $input->param('indicator');
-	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1") {
-        my %indicators;
-        for (my $i=0;$i<=$#ind_tag;$i++) {
-            $indicators{$ind_tag[$i]} = $indicator[$i];
-        }
-		$record = MARChtml2marc($dbh,\@tags,\@subfields,\@values,%indicators);
-# 		warn "RECORD : ".$record->as_formatted;
-	} else {
-		my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
-		$record=MARC::Record->new_from_xml($xml,C4::Context->preference('TemplateEncoding'),C4::Context->preference('marcflavour'));
-	}
-	#warn $record->as_formatted;
+	my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
+	$xml =~ s/collection/record/g;
+	warn "BEFORE".$xml;
+  	my $record=MARC::Record->new_from_xml($xml, 'UTF-8'); #,'UNIMARC'); #C4::Context->preference('TemplateEncoding'), C4::Context->preference('marcflavour'));
+	warn $record->as_formatted;
 	#warn "IN ADDBIB";
 	# check for a duplicate
 	my ($duplicatebiblionumber,$duplicatebibid,$duplicatetitle) = FindDuplicate($record) if ($op eq "addbiblio") && (!$is_a_modif);
@@ -552,31 +531,18 @@ if ($op eq "addbiblio") {
 } elsif ($op eq "addfield") {
 #------------------------------------------------------------------------------------------------------------------------------
 	my $addedfield = $input->param('addfield_field');
-	my $cntrepeatfield=$input->param('repeat_field');
-    $cntrepeatfield=1 unless ($cntrepeatfield);
-    my $tagaddfield_subfield = $input->param('addfield_subfield');
+	my $tagaddfield_subfield = $input->param('addfield_subfield');
 	my @tags = $input->param('tag');
 	my @subfields = $input->param('subfield');
 	my @values = $input->param('field_value');
 	# build indicator hash.
 	my @ind_tag = $input->param('ind_tag');
 	my @indicator = $input->param('indicator');
-    my $record;
-	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1") {
-        my %indicators;
-        for (my $i=0;$i<=$#ind_tag;$i++) {
-            $indicators{$ind_tag[$i]} = $indicator[$i];
-        }
-		$record = MARChtml2marc($dbh,\@tags,\@subfields,\@values,%indicators);
-	} else {
-		my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
-		$record=MARC::Record->new_from_xml($xml,C4::Context->preference('TemplateEncoding'),C4::Context->preference('marcflavour'));
-	}
-	for (my $i=1;$i<=$cntrepeatfield;$i++){
-        my $field = MARC::Field->new("$addedfield",'','',"$tagaddfield_subfield" => "");
-        $record->append_fields($field);
-    }
-    #warn "result : ".$record->as_formatted;
+	my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
+	my $record=MARC::Record->new_from_xml($xml, 'UTF-8'); #C4::Context->preference('TemplateEncoding'),C4::Context->preference('marcflavour'));
+	# adding an empty field
+	my $field = MARC::Field->new("$addedfield",'','','$tagaddfield_subfield' => "");
+	$record->append_fields($field);
 	build_tabs ($template, $record, $dbh,$encoding);
 	build_hidden_data;
 	$template->param(
