@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: additem.pl,v 1.27.2.22.2.2 2007/04/27 13:08:28 tipaul Exp $
+# $Id: additem.pl,v 1.27.2.19.2.1 2006/07/11 13:00:46 kados Exp $
 
 # Copyright 2000-2002 Katipo Communications
 #
@@ -75,19 +75,12 @@ if ($op eq "additem") {
 	# build indicator hash.
 	my @ind_tag = $input->param('ind_tag');
 	my @indicator = $input->param('indicator');
-	my @firstsubfields = $input->param('firstsubfields');
 	#my %indicators;
 	#for (my $i=0;$i<=$#ind_tag;$i++) {
 	#	$indicators{$ind_tag[$i]} = $indicator[$i];
 	#}
-	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1") {
-		$record = MARChtml2marc($dbh,\@tags,\@subfields,\@values,\@firstsubfields,\@indicator,\@ind_tag);
-	} else {
-		my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
-		$record=MARC::Record->new_from_xml($xml,C4::Context->preference('TemplateEncoding'),C4::Context->preference('marcflavour'));
-	}
-# 	my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
-#         my $record=MARC::Record::new_from_xml($xml, 'UTF-8');
+	my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
+        my $record=MARC::Record::new_from_xml($xml, 'UTF-8');
 	#my $record = MARChtml2marc($dbh,\@tags,\@subfields,\@values,%indicators);
 	# if autoBarcode is ON, calculate barcode...
 	if (C4::Context->preference('autoBarcode')) {
@@ -147,18 +140,13 @@ if ($op eq "additem") {
 	# build indicator hash.
 	my @ind_tag = $input->param('ind_tag');
 	my @indicator = $input->param('indicator');
-	my @firstsubfields = $input->param('firstsubfields');
 #	my $itemnum = $input->param('itemnum');
 	#my %indicators;
 	#for (my $i=0;$i<=$#ind_tag;$i++) {
 	#	$indicators{$ind_tag[$i]} = $indicator[$i];
 	#}
-	if (C4::Context->preference('TemplateEncoding') eq "iso-8859-1") {
-		$record = MARChtml2marc($dbh,\@tags,\@subfields,\@values,\@firstsubfields,\@indicator,\@ind_tag);
-	} else {
-		my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
-		$record=MARC::Record->new_from_xml($xml,C4::Context->preference('TemplateEncoding'),C4::Context->preference('marcflavour'));
-	}
+	my $xml = MARChtml2xml(\@tags,\@subfields,\@values,\@indicator,\@ind_tag);
+        my $record=MARC::Record::new_from_xml($xml, 'UTF-8');
 	#my $record = MARChtml2marc($dbh,\@tags,\@subfields,\@values,%indicators);
 # MARC::Record builded => now, record in DB
 # warn "R: ".$record->as_formatted;
@@ -189,9 +177,8 @@ my @fields = $temp->fields();
 my %witness; #---- stores the list of subfields used at least once, with the "meaning" of the code
 my @big_array;
 #---- finds where items.itemnumber is stored
-my $fwkcode = MARCfind_frameworkcode($dbh,$bibid);
-my ($itemtagfield,$itemtagsubfield) = &MARCfind_marc_from_kohafield($dbh,"items.itemnumber",$fwkcode);
-my ($branchtagfield,$branchtagsubfield) = &MARCfind_marc_from_kohafield($dbh,"items.homebranch",$fwkcode);
+my ($itemtagfield,$itemtagsubfield) = &MARCfind_marc_from_kohafield($dbh,"items.itemnumber",$itemtype);
+my ($branchtagfield,$branchtagsubfield) = &MARCfind_marc_from_kohafield($dbh,"items.homebranch",$itemtype);
 
 foreach my $field (@fields) {
 	next if ($field->tag()<10);
@@ -201,17 +188,8 @@ foreach my $field (@fields) {
 	for my $i (0..$#subf) {
 		next if ($tagslib->{$field->tag()}->{$subf[$i][0]}->{tab}  ne 10 && ($field->tag() ne $itemtagfield && $subf[$i][0] ne $itemtagsubfield));
 		$witness{$subf[$i][0]} = $tagslib->{$field->tag()}->{$subf[$i][0]}->{lib} if ($tagslib->{$field->tag()}->{$subf[$i][0]}->{tab}  eq 10);
-# 		$this_row{$subf[$i][0]} =$subf[$i][1] 
-		if ($tagslib->{$field->tag()}->{$subf[$i][0]}->{tab}  eq 10) {
-            if ($tagslib->{$field->tag()}->{$subf[$i][0]}->{isurl}) {
-                $this_row{$subf[$i][0]}="<a href=\"$subf[$i][1]\">$subf[$i][1]</a>";
-            } elsif ($tagslib->{$field->tag()}->{$subf[$i][0]}->{kohafield} eq "biblioitems.isbn") {
-                $this_row{$subf[$i][0]}=DisplayISBN($subf[$i][1]);
-            } else {
-                $this_row{$subf[$i][0]}=get_authorised_value_desc($field->tag(), $subf[$i][0], $subf[$i][1], '', $dbh);
-            }
-        }		
-		if (($field->tag eq $branchtagfield) && ($subf[$i][0] eq $branchtagsubfield) && C4::Context->preference("IndependantBranches")) {
+		$this_row{$subf[$i][0]} =$subf[$i][1] if ($tagslib->{$field->tag()}->{$subf[$i][0]}->{tab}  eq 10);
+		if (($field->tag eq $branchtagfield) && ($subf[$i][$0] eq $branchtagsubfield) && C4::Context->preference("IndependantBranches")) {
 			#verifying rights
 			my $userenv = C4::Context->userenv;
 			unless (($userenv->{'flags'} == 1) or (($userenv->{'branch'} eq $subf[$i][1]))){
@@ -283,17 +261,12 @@ foreach my $tag (sort keys %{$tagslib}) {
 					(C4::Context->userenv->{flags} != 1) && ($value) && ($value ne C4::Context->userenv->{branch}) ;
 # 		print $input->redirect(".pl?bibid=$bibid") if ($test);
 		# search for itemcallnumber if applicable
-##Lc callnumbers expect 2 subfields like 050ab or 090ab . Modified to accept 2 subfields
-warn "$value / $tag / $subfield";
-		if (!$value && $tagslib->{$tag}->{$subfield}->{kohafield} eq 'items.itemcallnumber' && C4::Context->preference('itemcallnumber')) {
+		if ($tagslib->{$tag}->{$subfield}->{kohafield} eq 'items.itemcallnumber' && C4::Context->preference('itemcallnumber')) {
 			my $CNtag = substr(C4::Context->preference('itemcallnumber'),0,3);
 			my $CNsubfield = substr(C4::Context->preference('itemcallnumber'),3,1);
-			my $CNsubfield2 = substr(C4::Context->preference('itemcallnumber'),4,1);
-			my $temp2 = $temp->field($CNtag);
-			if ($temp2) {
-				$value = ($temp2->subfield($CNsubfield)).' '.($temp2->subfield($CNsubfield2));
-#remove any trailing space incase one subfield is used
-			$value=~s/^\s+|\s+$//g;
+			my $temp = $record->field($CNtag);
+			if ($temp) {
+				$value = $temp->subfield($CNsubfield);
 			}
 		}
 		if ($tagslib->{$tag}->{$subfield}->{authorised_value}) {
@@ -342,7 +315,6 @@ warn "$value / $tag / $subfield";
 																		-default=>"$value",
 																		-labels => \%authorised_lib,
 																		-size=>1,
- 																		-tabindex=>'',
 																		-multiple=>0,
 																		);
 		} elsif ($tagslib->{$tag}->{$subfield}->{thesaurus_category}) {
@@ -353,7 +325,7 @@ warn "$value / $tag / $subfield";
 			require $plugin;
 			my $extended_param = plugin_parameters($dbh,$record,$tagslib,$i,0);
 			my ($function_name,$javascript) = plugin_javascript($dbh,$record,$tagslib,$i,0);
-			$subfield_data{marc_value}="<input type=\"text\" name=\"field_value\" value=\"$value\"  size=47 maxlength=255  OnFocus=\"javascript:Focus$function_name($i)\" OnBlur=\"javascript:Blur$function_name($i)\"> <a href=\"javascript:Clic$function_name($i)\">...</a> $javascript";
+			$subfield_data{marc_value}="<input type=\"text\" name=\"field_value\"  size=47 maxlength=255 DISABLE READONLY OnFocus=\"javascript:Focus$function_name($i)\" OnBlur=\"javascript:Blur$function_name($i)\"> <a href=\"javascript:Clic$function_name($i)\">...</a> $javascript";
 		} else {
 			$subfield_data{marc_value}="<input type=\"text\" name=\"field_value\" value=\"$value\" size=50 maxlength=255>";
 		}
@@ -384,30 +356,3 @@ foreach my $error (@errors) {
 	$template->param($error => 1);
 }
 output_html_with_http_headers $input, $cookie, $template->output;
-
-
-sub get_authorised_value_desc ($$$$$) {
-   my($tag, $subfield, $value, $framework, $dbh) = @_;
-
-   #---- branch
-    if ($tagslib->{$tag}->{$subfield}->{'authorised_value'} eq "branches" ) {
-       return getbranchname($value);
-    }
-
-   #---- itemtypes
-   if ($tagslib->{$tag}->{$subfield}->{'authorised_value'} eq "itemtypes" ) {
-       return ItemType($value);
-    }
-
-   #---- "true" authorized value
-   my $category = $tagslib->{$tag}->{$subfield}->{'authorised_value'};
-
-   if ($category ne "") {
-       my $sth = $dbh->prepare("select lib from authorised_values where category = ? and authorised_value = ?");
-       $sth->execute($category, $value);
-       my $data = $sth->fetchrow_hashref;
-       return $data->{'lib'};
-   } else {
-       return $value; # if nothing is found return the original value
-   }
-}
\ No newline at end of file
