@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: acquire.pl,v 1.18.2.6 2006/07/25 12:27:55 tipaul Exp $
+# $Id: acquire.pl,v 1.18.2.4 2006/03/07 16:57:47 oleonard Exp $
 
 #script to recieve orders
 #written by chris@katipo.co.nz 24/2/2000
@@ -41,7 +41,6 @@ my $dbh = C4::Context->dbh;
 
 my $search=$input->param('recieve');
 my $invoice=$input->param('invoice');
-my $datereceived=$input->param('datereceived');
 my $freight=$input->param('freight');
 my $biblio=$input->param('biblio');
 my $catview=$input->param('catview');
@@ -79,7 +78,6 @@ if ($count == 1){
 # 				-default  => $results[0]->{'itemtype'},
 # 				-labels   => \%itemtypes,
 # 				-size     => 1,
-# 				-tabindex=>'',
 # 				-multiple => 0 );
 # 	$sth->finish;
 
@@ -96,7 +94,6 @@ if ($count == 1){
 				-default  => $results[0]->{'branchcode'},
 				-labels   => \%select_branches,
 				-size     => 1,
- 				-tabindex=>'',
 				-multiple => 0 );
 
 	my $auto_barcode = C4::Context->boolean_preference("autoBarcode") || 0;
@@ -124,7 +121,6 @@ if ($count == 1){
 # 				-default  => $results[0]->{'bookfundid'},
 # 				-labels   => \%select_bookfunds,
 # 				-size     => 1,
-#				-tabindex=>'',
 # 				-multiple => 0 );
 
 	if ($results[0]->{'quantityreceived'} == 0){
@@ -141,7 +137,7 @@ if ($count == 1){
 		supplierid => $results[0]->{'booksellerid'},
 		freight => $freight,
 		gst => $gst,
-		catview => ($catview eq 'yes'?1:0),
+		catview => ($catview ne 'yes'?1:0),
 		name => $booksellers[0]->{'name'},
 		date => format_date($date),
 		title => $results[0]->{'title'},
@@ -158,8 +154,7 @@ if ($count == 1){
 		rrp => $results[0]->{'rrp'},
 		ecost => $results[0]->{'ecost'},
 		unitprice => $results[0]->{'unitprice'},
-        invoice => $invoice,
-        datereceived => $datereceived,
+		invoice => $invoice,
 		notes => $results[0]->{'notes'},
 		intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
 		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
@@ -175,8 +170,7 @@ if ($count == 1){
 		$line{quantityrecieved} = $results[$i]->{'quantityreceived'};
 		$line{ordernumber} = $results[$i]->{'ordernumber'};
 		$line{biblionumber} = $results[$i]->{'biblionumber'};
-        $line{invoice} = $invoice;
-        $line{datereceived} = $datereceived;
+		$line{invoice} = $invoice;
 		$line{freight} = $freight;
 		$line{gst} = $gst;
 		$line{title} = $results[$i]->{'title'};
@@ -189,10 +183,9 @@ if ($count == 1){
 						name => $booksellers[0]->{'name'},
 						supplierid => $supplierid,
 						invoice => $invoice,
-                        datereceived => $datereceived,
-                        intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
-                        intranetstylesheet => C4::Context->preference("intranetstylesheet"),
-                        IntranetNav => C4::Context->preference("IntranetNav"),
+		intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
 );
 
 }
