@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: basket.pl,v 1.24.2.13 2006/09/22 15:49:34 tipaul Exp $
+# $Id: basket.pl,v 1.24.2.9 2006/02/05 21:59:21 kados Exp $
 
 #script to show display basket of orders
 #written by chris@katipo.co.nz 24/2/2000
@@ -54,10 +54,6 @@ my $basket = getbasket($basketno);
 # warn "=>".$basket->{booksellerid};
 $booksellerid = $basket->{booksellerid} unless $booksellerid;
 my ($count2,@booksellers)=bookseller($booksellerid);
-$booksellers[0]->{'postal'} =~ s/\n/<br\/>/g;
-
-# get branches information, to show branchaddress in template
-my $branches = getbranches();
 
 # get librarian branch...
 if (C4::Context->preference("IndependantBranches")) {
@@ -77,7 +73,7 @@ if (C4::Context->preference("IndependantBranches")) {
 
 # if new basket, pre-fill infos
 $basket->{creationdate} = "" unless ($basket->{creationdate});
-$basket->{authorisedbyname} = $loggedinuser unless ($basket->{authorisedbyname});
+$basket->{authorisedby} = $loggedinuser unless ($basket->{authorisedby});
 ($count,@results)=getbasketcontent($basketno,'',$order);
 
 my $line_total; # total of each line
@@ -127,28 +123,30 @@ $grand_total=$sub_total+$gist;
 $grand_total_est = $sub_total_est+sprintf("%.2f",$sub_total_est*$prefgist);
 $gist_est = sprintf("%.2f",$sub_total_est*$prefgist);
 $template->param(basketno => $basketno,
-				creationdate => format_date($basket->{creationdate}),
+				creationdate => $basket->{creationdate},
+				authorisedby => $basket->{authorisedby},
 				authorisedbyname => $basket->{authorisedbyname},
 				closedate => format_date($basket->{closedate}),
 				active => $booksellers[0]->{'active'},
 				booksellerid=> $booksellers[0]->{'id'},
 				name => $booksellers[0]->{'name'},
-				postal => $booksellers[0]->{'postal'},
+				address1 => $booksellers[0]->{'address1'},
+				address2 => $booksellers[0]->{'address2'},
+				address3 => $booksellers[0]->{'address3'},
+				address4 => $booksellers[0]->{'address4'},
 				entrydate => format_date($results[0]->{'entrydate'}),
 				books_loop => \@books_loop,
 				count =>$count,
-				sub_total => sprintf("%.2f",$sub_total),
-				gist => sprintf("%.2f",$gist),
-				grand_total =>sprintf("%.2f",$grand_total),
-				sub_total_est => sprintf("%.2f",$sub_total_est),
-				gist_est => sprintf("%.2f",$gist_est),
-				grand_total_est =>sprintf("%.2f",$grand_total_est),
+				sub_total => $sub_total,
+				gist => $gist,
+				grand_total =>$grand_total,
+				sub_total_est => $sub_total_est,
+				gist_est => $gist_est,
+				grand_total_est =>$grand_total_est,
 				currency => $booksellers[0]->{'listprice'},
 				qty_total => $qty_total,
-				GST => C4::Context->preference("gist"),
-				branchname => $branches->{C4::Context->userenv->{branch}}->{branchname},
-				branchaddress1 => $branches->{C4::Context->userenv->{branch}}->{branchaddress1},
-				branchaddress2 => $branches->{C4::Context->userenv->{branch}}->{branchaddress2},
-				branchaddress3 => $branches->{C4::Context->userenv->{branch}}->{branchaddress3},
+				intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
 				);
 output_html_with_http_headers $query, $cookie, $template->output;
