@@ -106,7 +106,6 @@ my $CGIitemtype=CGI::scrolling_list( -name     => 'format',
 			-default  => $data->{'itemtype'},
 			-labels   => \%itemtypes,
 			-size     => 1,
-			-tabindex=>'',
 			-multiple => 0 );
 $sth->finish;
 
@@ -124,7 +123,6 @@ my $CGIbranch=CGI::scrolling_list( -name     => 'branch',
 			-default  => $data->{'branchcode'},
 			-labels   => \%select_branches,
 			-size     => 1,
-			-tabindex=>'',
 			-multiple => 0 );
 
 # build bookfund list
@@ -141,7 +139,6 @@ my $CGIbookfund=CGI::scrolling_list( -name     => 'bookfund',
 			-default  => $data->{'bookfundid'},
 			-labels   => \%select_bookfunds,
 			-size     => 1,
-			-tabindex=>'',
 			-multiple => 0 );
 my $bookfundname;
 my $bookfundid;
@@ -205,7 +202,9 @@ $template->param( existing => $biblio,
 						ecost => $data->{'ecost'},
 						notes => $data->{'notes'},
 						publishercode => $data->{'publishercode'},
-						GST => C4::Context->preference("gist"),
+						intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
 						);
 
 output_html_with_http_headers $input, $cookie, $template->output;
