@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: supplier.pl,v 1.9.2.6 2006/09/13 18:28:12 oleonard Exp $
+# $Id: supplier.pl,v 1.9.2.4 2006/02/20 14:58:13 hdl Exp $
 
 #script to show display basket of orders
 #written by chris@katipo.co.nz 24/2/2000
@@ -65,7 +65,6 @@ if ($op eq "display"){
 					contfax => $booksellers[0]->{'contfax'},
 					contemail => $booksellers[0]->{'contemail'},
 					contnotes => $booksellers[0]->{'contnotes'},
-					notes => $booksellers[0]->{'notes'},
 					active => $booksellers[0]->{'active'},
 					specialty => $booksellers[0]->{'specialty'},
 					gstreg => $booksellers[0]->{'gstreg'},
@@ -74,7 +73,9 @@ if ($op eq "display"){
 					discount => $booksellers[0]->{'discount'},
 					invoiceprice=>$booksellers[0]->{'invoiceprice'},
 					listprice=>$booksellers[0]->{'listprice'},
-					GST => C4::Context->preference("gist"),
+					intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+					intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+					IntranetNav => C4::Context->preference("IntranetNav"),
 					);
 }else{
 	my  ($count, $currencies) = &getcurrencies();
@@ -108,7 +109,6 @@ if ($op eq "display"){
 						contaltphone => $booksellers[0]->{'contaltphone'},
 						contfax => $booksellers[0]->{'contfax'},
 						contemail => $booksellers[0]->{'contemail'},
-						notes => $booksellers[0]->{'notes'},
 						contnotes => $booksellers[0]->{'contnotes'},
 						active => $booksellers[0]->{'active'},
 						specialty => $booksellers[0]->{'specialty'},
@@ -118,8 +118,10 @@ if ($op eq "display"){
 						discount => $booksellers[0]->{'discount'},
 						loop_pricescurrency => \@loop_pricescurrency,
 						loop_invoicecurrency => \@loop_invoicecurrency,
-						GST => C4::Context->preference("gist"),
-						enter=>1,
+						intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+			intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+			IntranetNav => C4::Context->preference("IntranetNav"),
+			enter=>1,
 						);
 }
 output_html_with_http_headers $query, $cookie, $template->output;
