@@ -21,6 +21,10 @@ my $dbh = C4::Context->dbh;
 my $sth = $dbh->prepare("select count(*) from stopwords");
 $sth->execute;
 my ($total) = $sth->fetchrow;
-$template->param(stopwords => $total);
+$template->param(stopwords => $total,
+		intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
+		intranetstylesheet => C4::Context->preference("intranetstylesheet"),
+		IntranetNav => C4::Context->preference("IntranetNav"),
+		);
 
 output_html_with_http_headers $query, $cookie, $template->output;
