@@ -58,7 +58,6 @@ my %tabsysprefs;
 	$tabsysprefs{KohaAdmin}="Admin";
 # Authorities
 	$tabsysprefs{authoritysep}="Authorities";
-	$tabsysprefs{AuthDisplayHierarchy}="Authorities";
 # Catalogue
 	$tabsysprefs{advancedMARCEditor}="Catalogue";
 	$tabsysprefs{autoBarcode}="Catalogue";
@@ -69,11 +68,7 @@ my %tabsysprefs;
 	$tabsysprefs{LabelMARCView}="Catalogue";
 	$tabsysprefs{marc}="Catalogue";
 	$tabsysprefs{marcflavour}="Catalogue";
-
 	$tabsysprefs{serialsadditems}="Catalogue";
-    $tabsysprefs{RoutingSerials}="Catalogue";
-	$tabsysprefs{ReceiveBackIssues}="Catalogue";
-
 	$tabsysprefs{sortbynonfiling}="Catalogue";
 	$tabsysprefs{MARCOrgCode}="Catalogue";
 	$tabsysprefs{z3950AuthorAuthFields}="Catalogue";
