@@ -2,7 +2,7 @@
 #script to provide bookshelf management
 # WARNING: This file uses 4-character tabs!
 #
-# $Header: /sources/koha/koha/bookshelves/addbookbybiblionumber.pl,v 1.3.2.4 2006/06/20 16:21:42 oleonard Exp $
+# $Header: /sources/koha/koha/bookshelves/addbookbybiblionumber.pl,v 1.3.2.3 2006/02/05 21:59:21 kados Exp $
 #
 # Copyright 2000-2002 Katipo Communications
 #
@@ -70,7 +70,6 @@ if ($shelfnumber) {
 				-values   => \@shelvesloop,
 				-labels   => \%shelvesloop,
 				-size     => 1,
-	 			-tabindex=>'',
 				-multiple => 0 );
 
 	$template->param(biblionumber => $biblionumber,
@@ -85,9 +84,6 @@ if ($shelfnumber) {
 	output_html_with_http_headers $query, $cookie, $template->output;
 }
 # $Log: addbookbybiblionumber.pl,v $
-# Revision 1.3.2.4  2006/06/20 16:21:42  oleonard
-# Adding "tabindex=''" to CGI:scrolling_lists to prevent incorrect tabbing. See Bug 1098
-#
 # Revision 1.3.2.3  2006/02/05 21:59:21  kados
 # Adds script support for IntranetNav ... see mail to koha-devel for
 # details
