@@ -2,7 +2,7 @@
 # NOTE: This file uses standard 8-space tabs
 #       DO NOT SET TAB SIZE TO 4
 
-# $Id: memberentry.pl,v 1.5.2.15 2006/09/26 10:04:16 tipaul Exp $
+# $Id: memberentry.pl,v 1.5.2.13 2006/02/05 21:59:21 kados Exp $
 
 #script to set up screen for modification of borrower details
 #written 20/12/99 by chris@katipo.co.nz
@@ -117,6 +117,7 @@ if ($op eq 'add' or $op eq 'modify') {
 			}
 		}
 	}
+	warn "==> ".format_date_in_iso($data{'joining'})." > ".format_date_in_iso($data{'expiry'});
 	if ($data{'expiry'} && format_date_in_iso($data{'joining'}) > format_date_in_iso($data{'expiry'})) {
 		push @errors, "ERROR_date";
 		warn "ERROR DATE";
@@ -185,7 +186,6 @@ if ($delete){
 	if ($ethnicitycategoriescount>=0) {
 		$ethcatpopup = CGI::popup_menu(-name=>'ethnicity',
 					-id => 'ethnicity',
-		 			-tabindex=>'',
 					-values=>$categories,
 					-default=>$data->{'ethnicity'},
 					-labels=>$labels);
@@ -195,7 +195,6 @@ if ($delete){
 	($categories,$labels)=borrowercategories();
 	my $catcodepopup = CGI::popup_menu(-name=>'categorycode',
 					-id => 'categorycode',
- 					-tabindex=>'',
 					-values=>$categories,
 					-default=>$data->{'categorycode'},
 					-labels=>$labels);
@@ -263,7 +262,6 @@ if ($delete){
 				-default  => $data->{'branchcode'},
 				-labels   => \%select_branches,
 				-size     => 1,
-	 			-tabindex=>'',
 				-multiple => 0 );
 	
 	my $CGIsort1 = buildCGIsort("Bsort1","sort1",$data->{'sort1'});
