@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: overdue.pl,v 1.9.2.12.2.1 2007/02/12 10:15:05 toins Exp $
+# $Id: overdue.pl,v 1.9.2.11.2.1 2006/07/11 14:18:26 kados Exp $
 
 # Copyright 2000-2002 Katipo Communications
 #
@@ -27,7 +27,6 @@ use HTML::Template;
 use C4::Auth;
 use C4::Koha;
 use C4::Acquisition;
-use C4::Date;
 
 my $input = new CGI;
 my $type=$input->param('type');
@@ -122,13 +121,11 @@ my $dbh = C4::Context->dbh;
 $bornamefilter =~s/\*/\%/g;
 $bornamefilter =~s/\?/\_/g;
 
-my $strsth="select date_due,concat(surname,' ', firstname) as borrower, 
-  borrowers.phone, borrowers.emailaddress,issues.itemnumber, biblio.title, biblio.author,borrowers.borrowernumber 
-  from issues
-LEFT JOIN borrowers ON (issues.borrowernumber=borrowers.borrowernumber )
-LEFT JOIN items ON (issues.itemnumber=items.itemnumber)
-LEFT JOIN biblioitems ON (biblioitems.biblioitemnumber=items.biblioitemnumber)
-LEFT JOIN biblio ON (biblio.biblionumber=items.biblionumber )
+my $strsth="select date_due,concat(surname,' ', firstname) as borrower, borrowers.phone, borrowers.emailaddress,issues.itemnumber, biblio.title, biblio.author,borrowers.borrowernumber from issues
+LEFT JOIN borrowers ON issues.borrowernumber=borrowers.borrowernumber 
+LEFT JOIN items ON issues.itemnumber=items.itemnumber
+LEFT JOIN biblioitems ON biblioitems.biblioitemnumber=items.biblioitemnumber
+LEFT JOIN biblio ON biblio.biblionumber=items.biblionumber 
 where isnull(returndate) ";
 $strsth.= " && date_due<'".$todaysdate."' " unless ($showall);
 $strsth.=" && (borrowers.firstname like '".$bornamefilter."%' or borrowers.surname like '".$bornamefilter."%' or borrowers.cardnumber like '".$bornamefilter."%')" if($bornamefilter) ;
@@ -136,18 +133,23 @@ $strsth.=" && borrowers.categorycode = '".$borcatfilter."' " if($borcatfilter) ;
 $strsth.=" && biblioitems.itemtype = '".$itemtypefilter."' " if($itemtypefilter) ;
 $strsth.=" && borrowers.flags = '".$borflagsfilter."' " if ($borflagsfilter ne " ") ;
 $strsth.=" && issues.branchcode = '".$branchfilter."' " if($branchfilter) ;
+# my $bornamefilter=$input->param('borname');
+# my $borcatfilter=$input->param('borcat');
+# my $itemtypefilter=$input->param('itemtype');
+# my $borflagsfilter=$input->param('borflags');
+# my $branchfilter=$input->param('branch');
 if ($order eq "borrower"){
 	$strsth.=" order by borrower,date_due " ;
 } else {
 	$strsth.=" order by date_due,borrower ";
 }
 my $sth=$dbh->prepare($strsth);
+warn "overdue.pl : query string ".$strsth;
 $sth->execute();
 
 my @overduedata;
 while (my $data=$sth->fetchrow_hashref) {
   $duedate=$data->{'date_due'};
-  $duedate = format_date($duedate);
   $itemnum=$data->{'itemnumber'};
 
   $name=$data->{'borrower'};
@@ -169,7 +171,6 @@ while (my $data=$sth->fetchrow_hashref) {
 }
 
 $sth->finish;
-$todaysdate=format_date($todaysdate);
 $template->param(todaysdate        => $todaysdate,
 		overdueloop       => \@overduedata,
 		intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
@@ -177,4 +178,4 @@ $template->param(todaysdate        => $todaysdate,
 		IntranetNav => C4::Context->preference("IntranetNav"),
 		);
 
-print $input->header(), $template->output;
+print "Content-Type: text/html\n\n", $template->output;
