@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: catalogue_stats.pl,v 1.10.2.5 2006/07/31 12:51:56 hdl Exp $
+# $Id: catalogue_stats.pl,v 1.10.2.4 2005/08/02 15:53:40 hdl Exp $
 
 # Copyright 2000-2002 Katipo Communications
 #
@@ -205,7 +205,7 @@ if ($do_it) {
 	my $branches=getbranches();
 	my %select_branches;
 	$select_branches{""} = "";
-	foreach my $branch (sort keys %$branches) {
+	foreach my $branch (keys %$branches) {
 		push @select, $branch;
 		$select_branches{$branch} = $branches->{$branch}->{'branchname'};
 	}
@@ -220,16 +220,9 @@ if ($do_it) {
 	$req->execute;
 	undef @select;
 	push @select,"";
-	my %select_location;
-	$select_location{""} = "";
-	while (my $items =$req->fetchrow_hashref) {
-		push @select, $items->{"holdingbranch"};
-		$select_location{$items->{'holdingbranch'}} = $branches->{$items->{'holdingbranch'}}->{'branchname'};
-	}
 	my $CGIlocation=CGI::scrolling_list( -name     => 'Filter',
 				-id => 'holdingbranch',
 				-values   => \@select,
-				-labels   => \%select_location,
 				-size     => 1,
 				-multiple => 0 );
 	
