@@ -97,15 +97,7 @@ my $dbh = C4::Context->dbh;
 
 my $startfrom=$query->param('startfrom');
 $startfrom=0 if(!defined $startfrom);
-my ($template, $loggedinuser, $cookie)
-    = get_template_and_user({template_name => "search.marc/result.tmpl",
-            query => $query,
-            type => $type,
-            authnotrequired => 0,
-            flagsrequired => {borrowers => 1},
-            flagsrequired => {catalogue => 1},
-            debug => 1,
-            });
+my ($template, $loggedinuser, $cookie);
 my $resultsperpage;
 
 if ($op eq "do_search") {
@@ -123,23 +115,20 @@ if ($op eq "do_search") {
 	# builds tag and subfield arrays
 	my @tags;
 
-	for (my $i=0;$i<=$#marclist;$i++) {
-		if ($marclist[$i] eq "biblioitems.isbn") {
-			$value[$i] =~ s/-//g;
-		}
-		if ($marclist[$i]) {
-			my ($tag,$subfield) = MARCfind_marc_from_kohafield($dbh,$marclist[$i],'');
+	foreach my $marc (@marclist) {
+		if ($marc) {
+			my ($tag,$subfield) = MARCfind_marc_from_kohafield($dbh,$marc,'');
 			if ($tag) {
 				push @tags,$dbh->quote("$tag$subfield");
 			} else {
-				if ($marclist[$i] =~ /^(\d){3}(. -)(.)*/)
+				if ($marc =~ /^(\d){3}(. -)(.)*/)
 				{
 					# The user is using the search catalogue part, more fields
-					push @tags, $dbh->quote(substr($marclist[$i],0,4));
+					push @tags, $dbh->quote(substr($marc,0,4));
 				}
 				else
 				{
-					push @tags, $marclist[$i];
+					push @tags, $marc;
 				}
 			}
 		} else {
@@ -161,6 +150,15 @@ if ($op eq "do_search") {
 	}
 	 exit
 	}
+	($template, $loggedinuser, $cookie)
+		= get_template_and_user({template_name => "search.marc/result.tmpl",
+				query => $query,
+				type => $type,
+				authnotrequired => 0,
+				flagsrequired => {borrowers => 1},
+				flagsrequired => {catalogue => 1},
+				debug => 1,
+				});
 
 	# multi page display gestion
 	my $displaynext=0;
@@ -311,7 +309,6 @@ else {
 	my $marclist = CGI::scrolling_list(-name=>"marclist",
 					-values=> $marcarray,
 					-size=>1,
-		 			-tabindex=>'',
 					-multiple=>0,
 					-onChange => "sql_update()",
 					);
@@ -338,7 +335,6 @@ else {
 				-values   => \@itemtype,
  				-labels   => \%itemtypes,
 				-size     => 1,
-	 			-tabindex=>'',
 				-multiple => 0 );
 	$sth->finish;
 
@@ -357,7 +353,6 @@ else {
 				-values   => \@select_branch,
 				-labels   => \%select_branches,
 				-size     => 1,
-	 			-tabindex=>'',
 				-multiple => 0 );
 	$sth->finish;
 
