@@ -24,7 +24,6 @@ use C4::Date;
 use MARC::Record;
 use C4::Suggestions;
 # use C4::Biblio;
-use Date::Calc qw(:all);
 
 use vars qw($VERSION @ISA @EXPORT);
 
@@ -87,7 +86,7 @@ get all basket informations in aqbasket for a given basket
 sub getbasket {
 	my ($basketno)=@_;
 	my $dbh=C4::Context->dbh;
-	my $sth=$dbh->prepare("select aqbasket.*,concat(borrowers.firstname,' ',borrowers.surname) as authorisedbyname from aqbasket left join borrowers on aqbasket.authorisedby=borrowers.borrowernumber where basketno=?");
+	my $sth=$dbh->prepare("select aqbasket.*,borrowers.firstname+' '+borrowers.surname as authorisedbyname from aqbasket left join borrowers on aqbasket.authorisedby=borrowers.borrowernumber where basketno=?");
 	$sth->execute($basketno);
 	return($sth->fetchrow_hashref);
 }
@@ -110,7 +109,7 @@ number of elements in C<@orders>.
 sub getbasketcontent {
 	my ($basketno,$supplier,$orderby)=@_;
 	my $dbh = C4::Context->dbh;
-	my $query="Select aqorderbreakdown.*,biblio.*,biblioitems.*,aqorders.*,biblio.title from biblio,biblioitems,aqorders
+	my $query="Select aqorderbreakdown.*,biblio.*,biblioitems.*,aqorders.*,biblio.title from aqorders,biblio,biblioitems
 	left join aqorderbreakdown on aqorderbreakdown.ordernumber=aqorders.ordernumber
 	where basketno='$basketno'
 	and biblio.biblionumber=aqorders.biblionumber and biblioitems.biblioitemnumber
@@ -318,23 +317,17 @@ Also updates the book fund ID in the aqorderbreakdown table.
 =cut
 #'
 sub receiveorder {
-	my ($biblio,$ordnum,$quantrec,$user,$cost,$invoiceno,$datereceived,$freight,$rrp)=@_;
-    my $dbh = C4::Context->dbh;
-    unless ($datereceived) {
-        # if datereceived is not set, calculate today date
-        my ($year,$month,$day) = Today();
-        $datereceived = "$year-$month-$day";
-    }
-	my $sth=$dbh->prepare("update aqorders set quantityreceived=?,datereceived=?,booksellerinvoicenumber=?,
+	my ($biblio,$ordnum,$quantrec,$user,$cost,$invoiceno,$freight,$rrp)=@_;
+	my $dbh = C4::Context->dbh;
+	my $sth=$dbh->prepare("update aqorders set quantityreceived=?,datereceived=now(),booksellerinvoicenumber=?,
 											unitprice=?,freight=?,rrp=?
 							where biblionumber=? and ordernumber=?");
 	my $suggestionid = findsuggestion_from_biblionumber($dbh,$biblio);
 	if ($suggestionid) {
 		changestatus($suggestionid,'AVAILABLE','',$biblio);
 	}
-	$sth->execute($quantrec,$datereceived,$invoiceno,$cost,$freight,$rrp,$biblio,$ordnum);
-    $sth->finish;
-    return $datereceived;
+	$sth->execute($quantrec,$invoiceno,$cost,$freight,$rrp,$biblio,$ordnum);
+	$sth->finish;
 }
 
 =item updaterecorder
@@ -503,8 +496,8 @@ sub getallorders {
   my ($supplierid)=@_;
   my $dbh = C4::Context->dbh;
   my @results = ();
-	my $strsth ="Select authorisedby,creationdate,aqbasket.basketno,
-closedate,surname,firstname,aqorders.biblionumber,aqorders.title, aqorders.ordernumber, quantity, quantityreceived
+	my $strsth ="Select count(*),authorisedby,creationdate,aqbasket.basketno,
+closedate,surname,firstname,aqorders.biblionumber,aqorders.title, aqorders.ordernumber 
 from aqorders 
 left join aqbasket on aqbasket.basketno=aqorders.basketno 
 left join borrowers on aqbasket.authorisedby=borrowers.borrowernumber
@@ -517,7 +510,7 @@ quantityreceived is NULL) and datecancellationprinted is NULL ";
 			$strsth .= " and (borrowers.branchcode = '".$userenv->{branch}."' or borrowers.branchcode ='')";
 		}
 	}
-	$strsth.=" order by aqbasket.basketno";
+	$strsth.=" group by basketno order by aqbasket.basketno";
 	my $sth=$dbh->prepare($strsth);
   $sth->execute($supplierid);
   while (my $data=$sth->fetchrow_hashref){
@@ -556,7 +549,7 @@ sub getparcelinformation {
 		}
 	}
 	$strsth.=" order by aqbasket.basketno";
-    ### parcelinformation : $strsth
+	### parcelinformation : $strsth
 	my $sth=$dbh->prepare($strsth);
   $sth->execute($supplierid);
   while (my $data=$sth->fetchrow_hashref){
@@ -667,6 +660,7 @@ sub getlateorders {
 		$strsth .= " AND borrowers.branchcode like \'".C4::Context->userenv->{branch}."\'" if (C4::Context->preference("IndependantBranches") && C4::Context->userenv->{flags}!=1);
 		$strsth .= " ORDER BY latesince,basketno,borrowers.branchcode, supplier";
 	}
+	warn "C4::Acquisition : getlateorders SQL:".$strsth;
 	my $sth = $dbh->prepare($strsth);
 	$sth->execute;
 	my @results;
@@ -746,11 +740,11 @@ sub ordersearch {
 	my @searchterms = ($id);
 	map { push(@searchterms,"$_%","% $_%") } @data;
 	push(@searchterms,$search,$search,$biblio);
-    my $sth=$dbh->prepare("SELECT biblio.*,biblioitems.*,aqorders.*,aqbasket.*,biblio.title from aqorders
-        LEFT JOIN aqbasket ON aqorders.basketno = aqbasket.basketno
-        LEFT JOIN biblioitems ON aqorders.biblioitemnumber = biblioitems.biblioitemnumber
-        LEFT JOIN biblio ON biblio.biblionumber=aqorders.biblionumber
-		where aqbasket.booksellerid = ?
+	my $sth=$dbh->prepare("Select biblio.*,biblioitems.*,aqorders.*,aqbasket.*,biblio.title from aqorders,biblioitems,biblio,aqbasket
+		where aqorders.biblioitemnumber = biblioitems.biblioitemnumber and
+		aqorders.basketno = aqbasket.basketno
+		and aqbasket.booksellerid = ?
+		and biblio.biblionumber=aqorders.biblionumber
 		and ((datecancellationprinted is NULL)
 		or (datecancellationprinted = '0000-00-00'))
 		and (("
@@ -796,8 +790,8 @@ sub histsearch {
 		$query .= " and biblio.title like ".$dbh->quote("%".$title."%") if $title;
 		$query .= " and biblio.author like ".$dbh->quote("%".$author."%") if $author;
 		$query .= " and name like ".$dbh->quote("%".$name."%") if $name;
-		$query .= " and creationdate >=" .$dbh->quote($from_placed_on) if $from_placed_on;
-		$query .= " and creationdate=<".$dbh->quote($to_placed_on) if $to_placed_on;
+		$query .= " and creationdate >" .$dbh->quote($from_placed_on) if $from_placed_on;
+		$query .= " and creationdate<".$dbh->quote($to_placed_on) if $to_placed_on;
 		if (C4::Context->preference("IndependantBranches")) {
 			my $userenv = C4::Context->userenv;
 			if (($userenv) &&($userenv->{flags} != 1)){
@@ -805,6 +799,7 @@ sub histsearch {
 			}
 		}
 		$query .=" order by booksellerid";
+		warn "query histearch: ".$query;
 		my $sth = $dbh->prepare($query);
 		$sth->execute;
 		my $cnt=1;
@@ -1080,6 +1075,7 @@ sub branches {
 		my $strsth ="Select * from branches ";
 		$strsth.= " WHERE branchcode = ".$dbh->quote(C4::Context->userenv->{branch});
 		$strsth.= " order by branchname";
+		warn "C4::Acquisition->branches : ".$strsth;
 		$sth=$dbh->prepare($strsth);
 	} else {
     	$sth = $dbh->prepare("Select * from branches order by branchname");
@@ -1119,17 +1115,17 @@ sub updatesup {
    contemail=?,contnotes=?,active=?,
    listprice=?, invoiceprice=?,gstreg=?, listincgst=?,
    invoiceincgst=?, specialty=?,discount=?,invoicedisc=?,
-   nocalc=?, notes=?
+   nocalc=?
    where id=?");
    $sth->execute($data->{'name'},$data->{'address1'},$data->{'address2'},
    $data->{'address3'},$data->{'address4'},$data->{'postal'},$data->{'phone'},
    $data->{'fax'},$data->{'url'},$data->{'contact'},$data->{'contpos'},
    $data->{'contphone'},$data->{'contfax'},$data->{'contaltphone'},
    $data->{'contemail'},
-   $data->{'contnotes'},$data->{'active'},$data->{'listprice'},
+   $data->{'contnote'},$data->{'active'},$data->{'listprice'},
    $data->{'invoiceprice'},$data->{'gstreg'},$data->{'listincgst'},
    $data->{'invoiceincgst'},$data->{'specialty'},$data->{'discount'},
-   $data->{'invoicedisc'},$data->{'nocalc'},$data->{'notes'},$data->{'id'});
+   $data->{'invoicedisc'},$data->{'nocalc'},$data->{'id'});
    $sth->finish;
 }
 
