@@ -196,16 +196,7 @@ sub get_template_and_user {
 			$template->param(CAN_user_tools => 1); }
 		
 	}
-	if  ($in->{'type'} eq "intranet") {
-        $template->param(
-                        intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),  
-                        intranetstylesheet => C4::Context->preference("intranetstylesheet"),
-                        IntranetNav => C4::Context->preference("IntranetNav"),
-
-        );
-
-	}
-        else {
+	unless ($in->{'type'} eq "intranet") {
 	$template->param(
 				suggestion => C4::Context->preference("suggestion"),
 				virtualshelves => C4::Context->preference("virtualshelves"),
@@ -496,7 +487,6 @@ sub checkauth {
 			intranetcolorstylesheet => C4::Context->preference("intranetcolorstylesheet"),
 			intranetstylesheet => C4::Context->preference("intranetstylesheet"),
 			IntranetNav => C4::Context->preference("IntranetNav"),
-			opacnav => C4::Context->preference("OpacNav"),
 			TemplateEncoding => C4::Context->preference("TemplateEncoding"),
 
 			);
