@@ -75,22 +75,22 @@ sub GetLateIssues {
 	my $dbh = C4::Context->dbh;
 	my $sth;
 	if ($supplierid) {
-            $sth = $dbh->prepare("SELECT name,title,planneddate,serialseq,serial.subscriptionid
-                    FROM subscription, serial, biblio
-                    LEFT JOIN aqbooksellers ON subscription.aqbooksellerid = aqbooksellers.id
-                    WHERE subscription.subscriptionid = serial.subscriptionid AND
-                    ((planneddate < now() and serial.STATUS =1) OR serial.STATUS = 3) and
-                    subscription.aqbooksellerid=$supplierid and
-                    biblio.biblionumber = subscription.biblionumber order by title
-                    ");
+		$sth = $dbh->prepare("SELECT name,title,planneddate,serialseq,serial.subscriptionid
+							FROM subscription, serial, biblio
+							LEFT JOIN aqbooksellers ON subscription.aqbooksellerid = aqbooksellers.id
+							WHERE subscription.subscriptionid = serial.subscriptionid AND
+							((planneddate < now() and serial.STATUS =1) OR serial.STATUS = 3) and
+							subscription.aqbooksellerid=$supplierid and
+							biblio.biblionumber = subscription.biblionumber order by title
+							");
 	} else {
 		$sth = $dbh->prepare("SELECT name,title,planneddate,serialseq,serial.subscriptionid
-                    FROM subscription, serial, biblio
-                    LEFT JOIN aqbooksellers ON subscription.aqbooksellerid = aqbooksellers.id
-                    WHERE subscription.subscriptionid = serial.subscriptionid AND
-                    ((planneddate < now() and serial.STATUS <=3) OR serial.STATUS = 3) and
-                    biblio.biblionumber = subscription.biblionumber order by title
-                    ");
+							FROM subscription, serial, biblio
+							LEFT JOIN aqbooksellers ON subscription.aqbooksellerid = aqbooksellers.id
+							WHERE subscription.subscriptionid = serial.subscriptionid AND
+							((planneddate < now() and serial.STATUS <=3) OR serial.STATUS = 3) and
+							biblio.biblionumber = subscription.biblionumber order by title
+							");
 	}
 	$sth->execute;
 	my @issuelist;
@@ -142,15 +142,15 @@ sub newsubscription {
 
 	# calculate issue number
 	my $serialseq = Get_Seq($val);
-	$sth = $dbh->prepare("insert into serial (serialseq,subscriptionid,biblionumber,status, planneddate,publisheddate) values (?,?,?,?,?,?)");
-    $sth->execute($serialseq, $subscriptionid, $val->{'biblionumber'}, 1, format_date_in_iso($startdate), format_date_in_iso($startdate));
+	$sth = $dbh->prepare("insert into serial (serialseq,subscriptionid,biblionumber,status, planneddate) values (?,?,?,?,?)");
+	$sth->execute($serialseq, $subscriptionid, $val->{'biblionumber'}, 1, format_date_in_iso($startdate));
 	return $subscriptionid;
 }
 
 sub getsubscription {
 	my ($subscriptionid) = @_;
 	my $dbh = C4::Context->dbh;
-	my $sth = $dbh->prepare('SELECT subscription.*,subscriptionhistory.*,aqbudget.bookfundid,aqbooksellers.name as aqbooksellername,biblio.title as bibliotitle, biblio.biblionumber as bibnum 
+	my $sth = $dbh->prepare('SELECT subscription.*,subscriptionhistory.*,aqbudget.bookfundid,aqbooksellers.name as aqbooksellername,biblio.title as bibliotitle 
 							from subscription 
 							left join subscriptionhistory on subscription.subscriptionid=subscriptionhistory.subscriptionid
 							left join aqbudget on subscription.aqbudgetid=aqbudget.aqbudgetid 
@@ -206,7 +206,7 @@ sub get_full_subscription_list_from_biblionumber {
   my $dbh = C4::Context->dbh;
   my $sth = $dbh->prepare('
   SELECT serial.serialseq,serial.planneddate, serial.publisheddate, serial.status, serial.notes,
-    year(IF(serial.publisheddate="00-00-0000",serial.planneddate,serial.publisheddate)) as year,
+    year(serial.publisheddate) as year,
     aqbudget.bookfundid,aqbooksellers.name as aqbooksellername,biblio.title as bibliotitle
   FROM serial 
         LEFT JOIN subscription ON 
@@ -215,10 +215,9 @@ sub get_full_subscription_list_from_biblionumber {
         LEFT JOIN aqbooksellers on subscription.aqbooksellerid=aqbooksellers.id 
         LEFT JOIN biblio on biblio.biblionumber=subscription.biblionumber 
   WHERE subscription.biblionumber = ? 
-  ORDER BY year,IF(serial.publisheddate="00-00-0000",serial.planneddate,serial.publisheddate),serial.subscriptionid');
+  ORDER BY year,serial.publisheddate,serial.subscriptionid,serial.planneddate');
 	$sth->execute($biblionumber);
 	my @res;
-    my %tmpresults;
 	my $year;
 	my $startdate;
 	my $aqbooksellername;
@@ -227,47 +226,44 @@ sub get_full_subscription_list_from_biblionumber {
 	my $first;
 	my $previousnote="";
 	while (my $subs = $sth->fetchrow_hashref) {
-        if ($subs->{'year'} && $subs->{'year'} ne ""){
-          $year=$subs->{'year'};
-        } else {
-          $year="1900"
-        }
-		if ($tmpresults{$year}){
-          my $temp=$tmpresults{$year}->{'serials'};
-          push @$temp,
-              {'publisheddate' =>($subs->{'publisheddate'}?format_date($subs->{'publisheddate'}):"XXX"),
-              'planneddate' => format_date($subs->{'planneddate'}), 
-              'serialseq' => $subs->{'serialseq'},
-              "status".$subs->{'status'} => 1,
-              'notes' => $subs->{'notes'} eq $previousnote?"":$subs->{notes},
-              };
+### BUG To FIX: When there is no published date, will create many null ids!!!
+
+		if ($year and ($year==$subs->{year})){
+			if ($first eq 1){$first=0;}
+			my $temp=$res[scalar(@res)-1]->{'serials'};
+			push @$temp,
+                {'publisheddate' =>format_date($subs->{'publisheddate'}),
+                'planneddate' => format_date($subs->{'planneddate'}), 
+                'serialseq' => $subs->{'serialseq'},
+                "status".$subs->{'status'} => 1,
+                'notes' => $subs->{'notes'} eq $previousnote?"":$subs->{notes},
+                };
 		}else {
-          $startdate= format_date($subs->{'startdate'});
-          $aqbooksellername= $subs->{'aqbooksellername'};
-          $bibliotitle= $subs->{'bibliotitle'};
-          my @temp;
-          push @temp,
-              {'publisheddate' =>($subs->{'publisheddate'}?format_date($subs->{'publisheddate'}):"XXX"),
-              'planneddate' => format_date($subs->{'planneddate'}), 
-              'serialseq' => $subs->{'serialseq'},
-              "status".$subs->{'status'} => 1,
-              'notes' => $subs->{'notes'} eq $previousnote?"":$subs->{notes},
-              };
-          $tmpresults{$year}={
-              'year'=>$year,
-              'nodate'=>($year eq "1900"),
-              'startdate'=>$startdate,
-              'aqbooksellername'=>$aqbooksellername,
-              'bibliotitle'=>$bibliotitle,
-              'serials'=>\@temp,
-              'first'=>$first 
-          };
-        } 
+			$first=1 if (not $year);
+			$year= $subs->{'year'};
+			$startdate= format_date($subs->{'startdate'});
+			$aqbooksellername= $subs->{'aqbooksellername'};
+			$bibliotitle= $subs->{'bibliotitle'};
+			my @temp;
+			push @temp,
+				{'publisheddate' =>format_date($subs->{'publisheddate'}),
+                'planneddate' => format_date($subs->{'planneddate'}), 
+				'serialseq' => $subs->{'serialseq'},
+				"status".$subs->{'status'} => 1,
+				'notes' => $subs->{'notes'} eq $previousnote?"":$subs->{notes},
+				};
+			
+			push @res,{
+				'year'=>$year,
+				'startdate'=>$startdate,
+				'aqbooksellername'=>$aqbooksellername,
+				'bibliotitle'=>$bibliotitle,
+				'serials'=>\@temp,
+				'first'=>$first 
+			};
+		}
 		$previousnote=$subs->{notes};
 	}
-    foreach my $key (keys %tmpresults){
-       push @res,$tmpresults{$key};
-    }
 	return \@res;
 }
 
@@ -370,16 +366,14 @@ sub getserials {
 	my $dbh = C4::Context->dbh;
 	# OK, now add the last 5 issues arrives/missing
 	my $sth=$dbh->prepare("
-  SELECT serialid, serialseq, status, publisheddate, planneddate, notes
-  FROM serial
+  SELECT serialid,serialseq, status, publisheddate,planneddate,notes 
+  FROM serial 
   WHERE subscriptionid = ? AND (status IN (2,4,5)) 
-  ORDER BY IF(serial.publisheddate=\"00-00-0000\",serial.planneddate,serial.publisheddate) DESC");
+  ORDER BY serialid DESC");
 	$sth->execute($subscriptionid);
 	my $counter=0;
-	my $syspref_counter = 0;
-	$syspref_counter = C4::Context->preference('ReceiveBackIssues') if C4::Context->preference('ReceiveBackIssues');
 	my @serials;
-	while((my $line = $sth->fetchrow_hashref) && $counter <$syspref_counter) {
+	while((my $line = $sth->fetchrow_hashref) && $counter <5) {
 		$counter++;
 		$line->{"status".$line->{status}} = 1; # fills a "statusX" value, used for template status select list
 		$line->{"publisheddate"} = format_date($line->{"publisheddate"});
@@ -393,6 +387,7 @@ sub getserials {
   FROM serial 
   WHERE subscriptionid = ? AND status NOT IN (2,4,5)");
 	$sth->execute($subscriptionid);
+	my @serials;
 	while(my $line = $sth->fetchrow_hashref) {
 		$line->{"status".$line->{status}} = 1; # fills a "statusX" value, used for template status select list
 		$line->{"publisheddate"} = format_date($line->{"publisheddate"});
@@ -410,14 +405,13 @@ sub getlatestserials{
 	my ($subscriptionid,$limit) =@_;
 	my $dbh = C4::Context->dbh;
 	# status = 2 is "arrived"
-	my $strsth="SELECT serialid,serialseq, status, publisheddate, planneddate FROM serial WHERE subscriptionid = ? AND (status =2 or status=4) ORDER BY IF(serial.publisheddate=\"00-00-0000\",serial.planneddate,serial.publisheddate) DESC LIMIT 0,$limit";
+	my $strsth="SELECT serialid,serialseq, status, planneddate FROM serial WHERE subscriptionid = ? AND (status =2 or status=4) ORDER BY planneddate DESC LIMIT 0,$limit";
 	my $sth=$dbh->prepare($strsth);
 	$sth->execute($subscriptionid);
 	my @serials;
 	while(my $line = $sth->fetchrow_hashref) {
 		$line->{"status".$line->{status}} = 1; # fills a "statusX" value, used for template status select list
 		$line->{"planneddate"} = format_date($line->{"planneddate"});
-		$line->{"publisheddate"} = format_date($line->{"publisheddate"});
 		push @serials,$line;
 	}
 	$sth=$dbh->prepare("SELECT count(*) from serial where subscriptionid=?");
@@ -443,11 +437,11 @@ sub serialchangestatus {
 		$sth = $dbh->prepare("SELECT missinglist,recievedlist from subscriptionhistory where subscriptionid=?");
 		$sth->execute($subscriptionid);
 		my ($missinglist,$recievedlist) = $sth->fetchrow;
-		if ($status eq 2 && ($serialseq!~/\(/ && $recievedlist!~/$serialseq/)) {
+		if ($status eq 2) {
 			$recievedlist .= ",$serialseq";
 		}
-		$missinglist .= ",$serialseq" if ($status eq 4 && ($serialseq!~/\(/ && $missinglist!~/$serialseq/)) ;
-		$missinglist .= ",not issued $serialseq" if ($status eq 5 && ($serialseq!~/\(/ && $missinglist!~/$serialseq/));
+		$missinglist .= ",$serialseq" if ($status eq 4) ;
+		$missinglist .= ",not issued $serialseq" if ($status eq 5);
 		$sth=$dbh->prepare("update subscriptionhistory set recievedlist=?, missinglist=? where subscriptionid=?");
 		$sth->execute($recievedlist,$missinglist,$subscriptionid);
 	}
@@ -460,7 +454,7 @@ sub serialchangestatus {
 		my ($newserialseq,$newlastvalue1,$newlastvalue2,$newlastvalue3,$newinnerloop1,$newinnerloop2,$newinnerloop3) = Get_Next_Seq($val);
 		# next date (calculated from actual date & frequency parameters)
 		my $nextpublisheddate = Get_Next_Date($publisheddate,$val);
-		newissue($newserialseq, $subscriptionid, $val->{'biblionumber'}, 1, $nextpublisheddate,$nextpublisheddate);
+		newissue($newserialseq, $subscriptionid, $val->{'biblionumber'}, 1, $nextpublisheddate,0);
 		$sth = $dbh->prepare("update subscription set lastvalue1=?, lastvalue2=?,lastvalue3=?,
 														innerloop1=?,innerloop2=?,innerloop3=?
 														where subscriptionid = ?");
@@ -469,9 +463,14 @@ sub serialchangestatus {
 }
 
 sub newissue {
-    my ($serialseq,$subscriptionid,$biblionumber,$status, $publisheddate, $planneddate) = @_;
+	my ($serialseq,$subscriptionid,$biblionumber,$status, $publisheddate, $planneddate) = @_;
 	my $dbh = C4::Context->dbh;
-	my $sth = $dbh->prepare("SELECT missinglist,recievedlist from subscriptionhistory where subscriptionid=?");
+	my $sth = $dbh->prepare("
+  INSERT INTO serial 
+    (serialseq,subscriptionid,biblionumber,status,publisheddate,planneddate) 
+  VALUES (?,?,?,?,?,?)");
+	$sth->execute($serialseq,$subscriptionid,$biblionumber,$status,$publisheddate, $planneddate);
+	$sth = $dbh->prepare("SELECT missinglist,recievedlist from subscriptionhistory where subscriptionid=?");
 	$sth->execute($subscriptionid);
 	my ($missinglist,$recievedlist) = $sth->fetchrow;
 	if ($status eq 2) {
@@ -482,11 +481,6 @@ sub newissue {
 	}
 	$sth=$dbh->prepare("update subscriptionhistory set recievedlist=?, missinglist=? where subscriptionid=?");
 	$sth->execute($recievedlist,$missinglist,$subscriptionid);
-	$sth = $dbh->prepare("
-  INSERT INTO serial 
-    (serialseq,subscriptionid,biblionumber,status,publisheddate,planneddate) 
-  VALUES (?,?,?,?,?,?)");
-	$sth->execute($serialseq,$subscriptionid,$biblionumber,$status,$publisheddate, $planneddate);
 }
 
 =head2 serialsitemize
@@ -502,7 +496,6 @@ sub serialsitemize {
 	my $sth=$dbh->prepare("SELECT * from serial WHERE serialid=?");
 	$sth->execute($serialid);
 	my $data=$sth->fetchrow_hashref;
-#     warn "biblionumber : ".$data->{biblionumber};
 	my $bibid=MARCfind_MARCbibid_from_oldbiblionumber($dbh,$data->{biblionumber});
 	my $fwk=MARCfind_frameworkcode($dbh,$bibid);
 	if ($info->{barcode}){
@@ -611,8 +604,7 @@ sub delissue {
 
 sub Get_Next_Date(@) {
 	my ($planneddate,$subscription) = @_;
-    my $resultdate;
-#     $planneddate = format_date($planneddate);
+	my $resultdate;
 	if ($subscription->{periodicity} == 1) {
 		$resultdate=DateCalc($planneddate,"1 day");
 	}
@@ -645,10 +637,8 @@ sub Get_Next_Date(@) {
 	}
 	if ($subscription->{periodicity} == 11) {
 		$resultdate=DateCalc($planneddate,"2 years");
-    }
-    $resultdate =~ /(....)(..)(..)/;
-    $resultdate="$1-$2-$3";
-    return $resultdate;
+	}
+    return format_date_in_iso($resultdate);
 }
 
 sub Get_Seq {
@@ -712,14 +702,12 @@ sub hassubscriptionexpired {
 	} else {
 		#a little bit more tricky if based on X weeks/months : search if the latest issue waited is not after subscription startdate + duration
 		my $sth = $dbh->prepare("SELECT max(planneddate) from serial where subscriptionid=?");
-        $sth->execute($subscriptionid);
-        my ($planneddate) = $sth->fetchrow;
-		my $res = ParseDate($planneddate);
+		$sth->execute($subscriptionid);
+		my $res = ParseDate(format_date_in_iso($sth->fetchrow));
 		my $endofsubscriptiondate;
-		$endofsubscriptiondate = DateCalc($subscription->{startdate},"+".$subscription->{monthlength}." months") if ($subscription->{monthlength});
-		$endofsubscriptiondate = DateCalc($subscription->{startdate},"+".$subscription->{weeklength}." weeks") if ($subscription->{weeklength});
-#         warn "res $res ($planneddate) : end : $endofsubscriptiondate ".$subscription->{startdate}." ".$subscription->{monthlength}." months";
-        return 1 if ($res >= $endofsubscriptiondate);
+		$endofsubscriptiondate = DateCalc(format_date_in_iso($subscription->{startdate}),$subscription->{monthlength}." months") if ($subscription->{monthlength});
+		$endofsubscriptiondate = DateCalc(format_date_in_iso($subscription->{startdate}),$subscription->{weeklength}." weeks") if ($subscription->{weeklength});
+		return 1 if ($res >= $endofsubscriptiondate);
 		return 0;
 	}
 }
