@@ -176,6 +176,10 @@ sub catalogsearch {
 	#		from marc_subfield_table as m1, marc_subfield_table as m2
 	#		where m1.bibid=m2.bibid and
 	#		(m1.subfieldvalue like "Des%" and m2.subfieldvalue like "27%")
+
+	# last minute stripping out of stuff
+	# doesn't work @$value =~ s/\'/ /;
+	# @$value = map { $_ =~ s/\'/ /g } @$value;
 	
 	# "Normal" statements
 	my @normal_tags = ();
@@ -190,10 +194,16 @@ sub catalogsearch {
 	my $any_not = 0;
 	$orderby = "biblio.title" unless $orderby;
 	$desc_or_asc = "ASC" unless $desc_or_asc;
+	#last minute stripping out of ' and ,
+# paul : quoting, it's done a few lines lated.
+# 	foreach $_ (@$value) {
+# 		$_=~ s/\'/ /g;
+# 		$_=~ s/\,/ /g;
+# 	}
 
-	# the item.notforloan contains an integer. Every value <>0 means "book unavailable for loan".
-	# but each library can have it's own table of meaning for each value. Get them
-	# 1st search if there is a list of authorised values connected to items.notforloan
+# the item.notforloan contains an integer. Every value <>0 means "book unavailable for loan".
+# but each library can have it's own table of meaning for each value. Get them
+# 1st search if there is a list of authorised values connected to items.notforloan
 	my $sth = $dbh->prepare('select authorised_value from marc_subfield_structure where kohafield="items.notforloan"');
 	$sth->execute;
 	my %notforloanstatus;
@@ -205,12 +215,13 @@ sub catalogsearch {
 			$notforloanstatus{$authorised_value} = $lib?$lib:$authorised_value;
 		}
 	}
-	for(my $i = 0 ; $i <= $#{$value} ; $i++) {
+	for(my $i = 0 ; $i <= $#{$value} ; $i++)
+	{
 		# replace * by %
 		@$value[$i] =~ s/\*/%/g;
 		# remove % at the beginning
 		@$value[$i] =~ s/^%//g;
-		@$value[$i] =~ s/(\.|\?|\:|\!|\'|,|\-|\"|\(|\)|\[|\]|\{|\}|\/|--)/ /g if @$operator[$i] eq "contains";
+	    @$value[$i] =~ s/(\.|\?|\:|\!|\'|,|\-|\"|\(|\)|\[|\]|\{|\}|\/|--)/ /g if @$operator[$i] eq "contains";
 		if(@$excluding[$i])	# NOT statements
 		{
 			$any_not = 1;
@@ -334,6 +345,10 @@ if (C4::Context->preference("sortbynonfiling")) {
 # subfield_string.  it's made without non-filing chars and you
 # sort by it ...
 # or maybe you just quer marc_subfield_table in the origiinal query.
+#
+#
+#
+#
 #
         if ($orderby eq "biblio.title") {    #don't sort by title if another orderby is specified
         		my ($tag,$subfieldcode) = MARCfind_marc_from_kohafield($dbh,'biblio.title','');
@@ -354,7 +369,7 @@ if (C4::Context->preference("sortbynonfiling")) {
 #                         warn "Here's the sorttitle beforehand: $titledat->{tag_indicator}=".$sorttitle;
                         if (length($titledat->{tag_indicator})==2) {
                                 my $filechar=substr($titledat->{tag_indicator},1,1);
-                                $sorttitle = substr($sorttitle,($filechar>length($sorttitle)?0:$filechar),-1,"");  #remove nonfiling characters
+                                $sorttitle = substr($sorttitle,$filechar,-1,"");  #remove nonfiling characters
 #                                warn "Here it is afterwards:".$sorttitle;
                         }
                         $titles{$bibidno} = $sorttitle; #} = $bibidno;
@@ -381,9 +396,9 @@ if (C4::Context->preference("sortbynonfiling")) {
 	# HINT : biblionumber as bn is important. The hash is fills biblionumber with items.biblionumber.
 	# so if you dont' has an item, you get a not nice empty value.
 	$sth = $dbh->prepare("SELECT biblio.biblionumber as bn,biblioitems.*,biblio.*, marc_biblio.bibid,itemtypes.notforloan,itemtypes.description
-							FROM  marc_biblio , biblio
-							LEFT JOIN biblioitems on ( biblio.biblionumber = biblioitems.biblionumber )
-							LEFT JOIN itemtypes on (itemtypes.itemtype=biblioitems.itemtype)
+							FROM biblio, marc_biblio 
+							LEFT JOIN biblioitems on biblio.biblionumber = biblioitems.biblionumber
+							LEFT JOIN itemtypes on itemtypes.itemtype=biblioitems.itemtype
 							WHERE biblio.biblionumber = marc_biblio.biblionumber AND bibid = ?");
         my $sth_subtitle = $dbh->prepare("SELECT subtitle FROM bibliosubtitle WHERE biblionumber=?"); # Added BY JF for Subtitles
 	my @finalresult = ();
@@ -392,33 +407,12 @@ if (C4::Context->preference("sortbynonfiling")) {
 	my $oldline;
 	my ($oldbibid, $oldauthor, $oldtitle);
 	my $sth_itemCN;
-	my $userenv=C4::Context->userenv;
-# 	warn "FLAGS : ".($userenv->{flags} & 2**9);
-    # hide lost items if :
-    # - the preference hidelostitems is set
-    # - the user not logged in, or is not a superlibrarian or a librarian with cataloguing permissions
-    # otherwise, show everything
-	if (!C4::Context->preference('hidelostitems') or ($userenv && ($userenv->{'flags'} eq 1 or ($userenv->{'flags'} & 2**9)) )) {
-	# show everything
-		$sth_itemCN = $dbh->prepare("
-  SELECT items.holdingbranch, items.location, items.itemcallnumber, count(*) AS cnt, items.itemnumber, items.notforloan
-  FROM items 
-  WHERE biblionumber=? 
-  GROUP BY items.holdingbranch, items.location, items.itemcallnumber 
-  ORDER BY homebranch");
+	if (C4::Context->preference('hidelostitems')) {
+		$sth_itemCN = $dbh->prepare("select items.* from items where biblionumber=? and (itemlost = 0 or itemlost is NULL) order by homebranch");
 	} else {
-	# hide lost items
-		$sth_itemCN = $dbh->prepare("
-  SELECT items.holdingbranch, items.location, items.itemcallnumber, count(*) AS cnt, items.itemnumber, items.notforloan
-  FROM items 
-  WHERE biblionumber=? AND (itemlost = 0 OR itemlost IS NULL)
-  GROUP BY items.holdingbranch, items.location, items.itemcallnumber
-  ORDER BY homebranch");
+		$sth_itemCN = $dbh->prepare("select items.* from items where biblionumber=? order by homebranch");
 	}
-	my $sth_issue = $dbh->prepare("
-  SELECT date_due,returndate 
-  FROM issues 
-  WHERE itemnumber=?");
+	my $sth_issue = $dbh->prepare("select date_due,returndate from issues where itemnumber=?");
 	# parse all biblios between start & end.
 	while (($counter <= $#result) && ($counter <= ($offset + $length))) {
 		# search & parse all items & note itemcallnumber
@@ -446,27 +440,24 @@ if (C4::Context->preference("sortbynonfiling")) {
 			# then all other fields in the main array
 			
 			# search if item is on loan
+			my $date_due;
+			$sth_issue->execute($item->{itemnumber});
+			while (my $loan = $sth_issue->fetchrow_hashref) {
+				if ($loan->{date_due} and !$loan->{returndate}) {
+					$date_due = $loan->{date_due};
+				}
+			}
 			# store this item
 			my %lineCN;
 			$lineCN{holdingbranch} = $item->{holdingbranch};
 			$lineCN{itemcallnumber} = $item->{itemcallnumber};
 			$lineCN{location} = $item->{location};
-			$lineCN{cnt} = $item->{cnt} unless ($item->{cnt}==1);
-            if ($item->{cnt}==1){
-              my $date_due;
-              $sth_issue->execute($item->{itemnumber});
-              while (my $loan = $sth_issue->fetchrow_hashref) {
-                  if ($loan->{date_due} and !$loan->{returndate}) {
-                      $date_due = $loan->{date_due};
-                  }
-              }
-              $lineCN{date_due} = format_date($date_due) ;
-              $lineCN{notforloan} = $notforloanstatus{$item->{notforloan}} if ($item->{notforloan}); # setting not forloan it this item is not for loan
-            }
-            $notforloan=0 unless ($item->{notforloan} or $item->{wthdrawn} or $item->{itemlost});
-			$lineCN{notforloan} = $notforloanstatus{$line->{notforloan}} if ($line->{notforloan} and not $lineCN{notforloan}); # setting not forloan if itemtype is not for loan
+			$lineCN{date_due} = format_date($date_due);
+			$lineCN{notforloan} = $notforloanstatus{$line->{notforloan}} if ($line->{notforloan}); # setting not forloan if itemtype is not for loan
+			$lineCN{notforloan} = $notforloanstatus{$item->{notforloan}} if ($item->{notforloan}); # setting not forloan it this item is not for loan
+			$notforloan=0 unless ($item->{notforloan} or $item->{wthdrawn} or $item->{itemlost});
 			push @CNresults,\%lineCN;
-			$totalitems+=$item->{cnt};
+			$totalitems++;
 		}
 		# save the biblio in the final array, with item and item issue status
 		my %newline;
@@ -499,7 +490,6 @@ if (C4::Context->preference("sortbynonfiling")) {
 	return (\@finalresult, $nbresults);
 }
 
-
 # Creates the SQL Request
 
 sub create_request {
@@ -522,7 +512,6 @@ sub create_request {
 					$sql_tables .= "marc_subfield_table as m$nb_table,";
 					$sql_where1 .= "(m1.subfieldvalue like ".$dbh->quote("@$value[$i]%");
 					if (@$tags[$i]) {
-                        @$tags[$i] = $dbh->quote(@$tags[$i]) unless @$tags[$i]=~ /^'/;
 						$sql_where1 .=" and concat(m1.tag,m1.subfieldcode) in (@$tags[$i])";
 					}
 					$sql_where1.=")";
@@ -530,7 +519,6 @@ sub create_request {
 					$sql_tables .= "marc_word as m$nb_table,";
 					$sql_where1 .= "(m1.word  like ".$dbh->quote("@$value[$i]");
 					if (@$tags[$i]) {
-                        @$tags[$i] = $dbh->quote(@$tags[$i]) unless @$tags[$i]=~ /^'/;
 						 $sql_where1 .=" and m1.tagsubfield in (@$tags[$i])";
 					}
 					$sql_where1.=")";
@@ -538,7 +526,6 @@ sub create_request {
 					$sql_tables .= "marc_subfield_table as m$nb_table,";
 					$sql_where1 .= "(m1.subfieldvalue @$operator[$i] ".$dbh->quote("@$value[$i]");
 					if (@$tags[$i]) {
-                        @$tags[$i] = $dbh->quote(@$tags[$i]) unless @$tags[$i]=~ /^'/;
 						 $sql_where1 .=" and concat(m1.tag,m1.subfieldcode) in (@$tags[$i])";
 					}
 					$sql_where1.=")";
@@ -549,7 +536,6 @@ sub create_request {
 					$sql_tables .= "marc_subfield_table as m$nb_table,";
 					$sql_where1 .= "@$and_or[$i] (m$nb_table.subfieldvalue like ".$dbh->quote("@$value[$i]%");
 					if (@$tags[$i]) {
-                        @$tags[$i] = $dbh->quote(@$tags[$i]) unless @$tags[$i]=~ /^'/;
 					 	$sql_where1 .=" and concat(m$nb_table.tag,m$nb_table.subfieldcode) in (@$tags[$i])";
 					}
 					$sql_where1.=")";
@@ -560,7 +546,6 @@ sub create_request {
 						$sql_tables .= "marc_word as m$nb_table,";
 						$sql_where1 .= "@$and_or[$i] (m$nb_table.word like ".$dbh->quote("@$value[$i]");
 						if (@$tags[$i]) {
-                            @$tags[$i] = $dbh->quote(@$tags[$i]) unless @$tags[$i]=~ /^'/;
 							$sql_where1 .=" and m$nb_table.tagsubfield in(@$tags[$i])";
 						}
 						$sql_where1.=")";
@@ -568,7 +553,6 @@ sub create_request {
 					} else {
 						$sql_where1 .= "@$and_or[$i] (m$nb_table.word like ".$dbh->quote("@$value[$i]");
 						if (@$tags[$i]) {
-                            @$tags[$i] = $dbh->quote(@$tags[$i]) unless @$tags[$i]=~ /^'/;
 							$sql_where1 .="  and m$nb_table.tagsubfield in (@$tags[$i])";
 						}
 						$sql_where1.=")";
@@ -579,7 +563,6 @@ sub create_request {
 					$sql_tables .= "marc_subfield_table as m$nb_table,";
 					$sql_where1 .= "@$and_or[$i] (m$nb_table.subfieldvalue @$operator[$i] ".$dbh->quote(@$value[$i]);
 					if (@$tags[$i]) {
-                        @$tags[$i] = $dbh->quote(@$tags[$i]) unless @$tags[$i]=~ /^'/;
 					 	$sql_where1 .="  and concat(m$nb_table.tag,m$nb_table.subfieldcode) in (@$tags[$i])";
 					}
 					$sql_where2 .= "m1.bibid=m$nb_table.bibid and ";
@@ -659,9 +642,9 @@ sub getMARCsubjects {
 		$maxtag = "699";
 	} else {           # assume unimarc if not marc21
 		$mintag = "600";
-		$maxtag = "611";
+		$maxtag = "699";
 	}
-	my $sth=$dbh->prepare("SELECT `subfieldvalue`,`subfieldcode`,`tagorder`,`tag` FROM `marc_subfield_table` WHERE `bibid`= ? AND `subfieldcode` NOT IN ('2','3','4','6','8') AND `tag` BETWEEN ? AND ? ORDER BY `tagorder`,`subfieldorder`");
+	my $sth=$dbh->prepare("SELECT `subfieldvalue`,`subfieldcode`,`tagorder`,`tag` FROM `marc_subfield_table` WHERE `bibid`= ? AND `subfieldcode` NOT IN ('2','4','6','8') AND `tag` BETWEEN ? AND ? ORDER BY `tagorder`,`subfieldorder`");
 	# Subfield exclusion for $2, $4, $6, $8 protects against searching for
 	# variant data in otherwise invariant authorised subject headings when all
 	# returned subfields are used to form a query for matching subjects.  One
